searchData={"items":[{"type":"module","title":"DataframeTools","doc":"DataframeTools is designed to help you work with Explorer.DataFrame.\n\nI found myself having the same problems time and time again eg. converting strings to dates/datetimes or\nconverting string columns to categories","ref":"DataframeTools.html"},{"type":"module","title":"DataframeTools.Date","doc":"","ref":"DataframeTools.Date.html"},{"type":"function","title":"DataframeTools.Date.convert_column_to_date/2","doc":"Automagically try and convert a column in a dataframe to a date or datetime.\nIt will check to see if the first 10 items in that column are dates,\nbased on zero padding eg. 2021-01-01 yyyy-mm-dd\nand if so, convert to a date.  If not, convert to a datetime.\n\nTODO: look at converting numbers in a reasonable timestamp range to datetimes","ref":"DataframeTools.Date.html#convert_column_to_date/2"},{"type":"function","title":"Examples - DataframeTools.Date.convert_column_to_date/2","doc":"iex> df = Explorer.DataFrame.new(%{\n    ...>   dates: Explorer.Series.from_list(~w(2010-01-01 2020-02-01)),\n    ...>   datetimes: Explorer.Series.from_list([1, nil])\n    ...> })\n    iex> df2 = DataframeTools.Date.convert_column_to_date(df, :dates)\n    iex> Explorer.DataFrame.dtypes(df2)\n    %{\"dates\" => :date, \"datetimes\" => {:s, 64}}\n\n\n    iex> df = Explorer.DataFrame.new(%{\n    ...>   dates: Explorer.Series.from_list(~w(2010-01-01 2020-02-01)),\n    ...>   datetimes: Explorer.Series.from_list([\"2024-04-25T13:05:41+10:00\", \"2024-04-01T13:05:41+10:00\"])\n    ...> })\n    iex> df3 = DataframeTools.Date.convert_column_to_date(df, :datetimes)\n    iex> Explorer.DataFrame.dtypes(df3)\n    %{\"dates\" => :string, \"datetimes\" => {:datetime, :microsecond}}","ref":"DataframeTools.Date.html#convert_column_to_date/2-examples"},{"type":"module","title":"DataframeTools.String","doc":"","ref":"DataframeTools.String.html"},{"type":"function","title":"DataframeTools.String.categorise_columns/1","doc":"Converts all string columns in a DataFrame to categories where n_unique items < half total items.\nThis is just a way to make more efficient use of memory and faster joins.","ref":"DataframeTools.String.html#categorise_columns/1"},{"type":"function","title":"Examples - DataframeTools.String.categorise_columns/1","doc":"iex> df = Explorer.DataFrame.new(%{\n    ...>   names: Explorer.Series.from_list(~w(bob bob bob harry tom tom harry bob bob bob)),\n    ...>   unique_names: Explorer.Series.from_list(~w(a bcob c d e f g h i j))\n    ...> })\n    iex> df2 = DataframeTools.String.categorise_columns(df)\n    iex> Explorer.DataFrame.dtypes(df2)\n    %{\"names\" => :category, \"unique_names\" => :string}","ref":"DataframeTools.String.html#categorise_columns/1-examples"},{"type":"extras","title":"Explorer Cheatsheet!","doc":"# Explorer Cheatsheet!\n\nThis is really a set of tips for Explorer.DataFrame because I find it was hard for newcomers to elixir.","ref":"explorer.html"},{"type":"extras","title":"Manipulating Dataframes - Explorer Cheatsheet!","doc":"{: .col-1}","ref":"explorer.html#manipulating-dataframes"},{"type":"extras","title":"Starting - Explorer Cheatsheet!","doc":"#### Before you start, including macro support\n\n```elixir\nrequire Explorer.DataFrame, as: DF\n```\n\nThis allows queries to be more simple, referencing columns (a series in explorer) directly, rather than using [] \non a dataframe.  It also means you can write `DF. ` rather than `Explorer.DataFrame. `.","ref":"explorer.html#starting"},{"type":"extras","title":"Analysis - Explorer Cheatsheet!","doc":"#### Checking the types of columns\n\n```elixir\nDF.dtypes(df)\n```\n\n####","ref":"explorer.html#analysis"},{"type":"extras","title":"Conversion - Explorer Cheatsheet!","doc":"{: .col-1}\n\n#### Fixing the weird syntax\n\n```elixir\nDF.mutate_with(df, &[c: Explorer.Series.add(&1[\"a\"], &1[\"b\"])])\n\n# is just another way to say\n\nDF.mutate_with(df, fn lazy_df -> \n  %{\n    c: Explorer.Series.add(lazy_df[\"a\"], lazy_df[\"b\"])\n  }\nend)\n```\n\n\n\n#### Converting a column from string to category\n\n```elixir\nDF.mutate(df, %{col_name => Explorer.Series.cast(df[col_name], :category)})\n```\n\n#### Converting a column from string to a datetime\n\n```elixir\nDF.mutate(df, %{col_name => Explorer.Series.strptime(df[column_name], \"%+\")})\n```","ref":"explorer.html#conversion"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}